# Documentation for `ImbalancedDataTransformer`
::: photonai.modelwrapper.imbalanced_data_transformer.ImbalancedDataTransformer
    selection:
      members:
        - __init__
        - transform
        - fit_transform
